unit Main;

interface

uses
  SysUtils, Windows, Messages, Graphics, Controls,
  Forms, Dialogs, StdCtrls, Classes, ExtCtrls, MsgSock, objdeb;

type
  TFormMain = class(TForm)
    BtnConnect: TButton;
    BtnSend: TButton;
    BtnPost: TButton;
    BtnClose: TButton;
    MessageSocket: TMessageSocket;
    procedure MessageSocketSentMessage(Sender: TObject; const MessageID: Word;
      const SourceHandle: Integer; const DataPtr: Pointer;
      const DataSize: Word);
    procedure BtnConnectClick(Sender: TObject);
    procedure BtnSendClick(Sender: TObject);
    procedure BtnPostClick(Sender: TObject);
    procedure BtnCloseClick(Sender: TObject);
  private
    I: Longint;
    DestHandle: Hwnd;
  end;

var
  FormMain: TFormMain;

implementation

{$R *.DFM}

{
Message Socket Property Values
	HighMessageID = 110
  LowMessageID = 100
  	Two TMessageSocket component ignore each other if their LowMessageIDs are different.
    Moreover, only MessageID between LowMessageID + 1 and HighMessageID can be used.
  PostSupport = false
    This component does not receive Posted Messages, so PostSupport can be set to False
    to save resources.
  PostThreadPriority = tpHigher
    As PostSupport = false this is not rilevant.
}

{This event is fired when MessageSock in APP1 answers to the message sent by
 BroadcastIdentity. SourceHandle has to be saved and used to address messages to APP1}

procedure TFormMain.MessageSocketSentMessage(Sender: TObject;
  const MessageID: Word; const SourceHandle: Integer; const DataPtr: Pointer;
  const DataSize: Word);
begin

	if MessageID = MessageSocket.LowMessageID then {This is to check message origin}
  	DestHandle := SourceHandle;

end;

procedure TFormMain.BtnConnectClick(Sender: TObject);
begin

	{BroadcastIdentity signals to MessageSock in APP1}
	MessageSocket.BroadcastIdentity;
  I := 0;

end;

procedure TFormMain.BtnSendClick(Sender: TObject);

var
	S: string[128];

begin

	Inc(I);
  S := 'Sent: ' + IntToStr(I);
  {This SendMessage sends sincronously to APP1 a message containing the string S}
  MessageSocket.SendMessage(101,DestHandle,@S[1],Length(S));

end;

procedure TFormMain.BtnPostClick(Sender: TObject);

var
	S: string[128];

begin

	Inc(I);
  S := 'Post: ' + IntToStr(I);
  {This PostMessage posts asincronously to APP1 a message containing the string S}
  MessageSocket.PostMessage(102,DestHandle,@S[1],Length(S));

end;

procedure TFormMain.BtnCloseClick(Sender: TObject);
begin

  {This SendMessage sends sincronously to APP1 a message without any data to
   request its termination. This is potentially unsafe because if APP1
   terminates inside the event handler this application may be blocked forever.
   The MessageHandled method is provided to solve just this kind of problems. }
  MessageSocket.SendMessage(103,DestHandle,nil,0);
  Application.Terminate;

end;


end.

